@@ -1,8 +1,8 @@
-use strict;
-use warnings;
-package Dist::Zilla::App::Command::authordeps 6.010;
+package Dist::Zilla::App::Command::authordeps 6.037;
 # ABSTRACT: List your distribution's author dependencies
 
+use Dist::Zilla::Pragmas;
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -16,6 +16,10 @@ use Dist::Zilla::App -command;
 #pod
 #pod   ; authordep Some::Package
 #pod
+#pod In order to add authordeps to all distributions that use a certain plugin bundle
+#pod (or plugin), just list them as prereqs of that bundle (e.g.: using
+#pod L<Dist::Zilla::Plugin::Prereqs> ).
+#pod
 #pod =cut
 
 sub abstract { "list your distribution's author dependencies" }
@@ -25,6 +29,7 @@ sub opt_spec {
     [ 'root=s' => 'the root of the dist; defaults to .' ],
     [ 'missing' => 'list only the missing dependencies' ],
     [ 'versions' => 'include required version numbers in listing' ],
+    [ 'cpanm-versions' => 'format versions for consumption by cpanm' ],
   );
 }
 
@@ -34,11 +39,13 @@ sub execute {
   require Dist::Zilla::Path;
   require Dist::Zilla::Util::AuthorDeps;
 
-  my $deps = Dist::Zilla::Util::AuthorDeps::format_author_deps(
+  my $deps = Dist::Zilla::Util::AuthorDeps::_format_author_deps(
     Dist::Zilla::Util::AuthorDeps::extract_author_deps(
       Dist::Zilla::Path::path($opt->root // '.'),
       $opt->missing,
-    ), $opt->versions
+    ),
+    $opt->versions,
+    $opt->cpanm_versions
   );
 
   $self->log($deps) if $deps;
@@ -60,7 +67,7 @@ Dist::Zilla::App::Command::authordeps - List your distribution's author dependen
 
 =head1 VERSION
 
-version 6.010
+version 6.037
 
 =head1 SYNOPSIS
 
@@ -73,13 +80,30 @@ results by using special comments in the form:
 
   ; authordep Some::Package
 
+In order to add authordeps to all distributions that use a certain plugin bundle
+(or plugin), just list them as prereqs of that bundle (e.g.: using
+L<Dist::Zilla::Plugin::Prereqs> ).
+
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo SIGNES.
+This software is copyright (c) 2026 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
